@@ -9,11 +9,11 @@ register = Library()
 
 
 @register.inclusion_tag('whatsnew/whatsnew.html', takes_context=True)
-def whatsnew(context, package_name):
+def whatsnew(context, package_name, force=1):
     cookie_name = "{}-whatsnew".format(package_name)
 
     display, news = display_message(context['request'], package_name, cookie_name)
 
     return {'name': cookie_name,
-            'display': display,
+            'display': display or force,
             'news': news}
